This is an automated email from the ASF dual-hosted git repository.

shanedell pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/daffodil-vscode.git


The following commit(s) were added to refs/heads/main by this push:
     new 0ce6dd1  Multiple Updates:
0ce6dd1 is described below

commit 0ce6dd1d3ecaaf09682c3ddacd49a0250f8adcee
Author: Shane Dell <[email protected]>
AuthorDate: Fri Feb 18 11:18:59 2022 -0500

    Multiple Updates:
    
    - Update apache daffodil logo to be png not svg
    - Fix icon issue by:
      - Downloading apache daffodil logo locally to images folder
      - Fix path to it in package.json "images/daffodil.ico"
    - Update binary name so that when yarn build run it creates 
"apache-daffodil-vscode-VERSION.vsix"
      - change "name" attribute inside of package.json to 
"apache-daffodil-vscode"
    - Update ratchCheck to ignore "images/daffodil.ico" instead of 
"images/daffodil.jpg"
    
    Closes #81
    Closes #82
    Closes #83
---
 README.md           |   2 +-
 images/daffodil.ico | Bin 0 -> 116317 bytes
 package.json        |   6 +++---
 project/Rat.scala   |   4 ++--
 4 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/README.md b/README.md
index 13eb18c..501a1da 100644
--- a/README.md
+++ b/README.md
@@ -18,7 +18,7 @@
 
 <div align="center">
 
-<img 
src="https://daffodil.apache.org/assets/themes/apache/img/apache-daffodil-logo.svg";
 height="85" alt="Apache Daffodil"/>
+<img 
src="https://daffodil.apache.org/assets/themes/apache/img/apache-daffodil-logo.png";
 height="85" alt="Apache Daffodil"/>
 
 # Apache Daffodil VS Code Extension
 
diff --git a/images/daffodil.ico b/images/daffodil.ico
new file mode 100644
index 0000000..42cd59b
Binary files /dev/null and b/images/daffodil.ico differ
diff --git a/package.json b/package.json
index 460076a..d8b4a3c 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
 {
-  "name": "daffodil-debugger",
-  "displayName": "Apache Daffodil Schema Debugger",
+  "name": "apache-daffodil-vscode",
+  "displayName": "Apache Daffodil VS Code Extension",
   "description": "VS Code extension for Apache Daffodil DFDL schema debugging",
   "version": "1.0.0-SNAPSHOT",
   "daffodilVersion": "3.2.1",
@@ -10,7 +10,7 @@
   "engines": {
     "vscode": "^1.55.0"
   },
-  "icon": "images/daffodil.jpg",
+  "icon": "images/daffodil.ico",
   "categories": [
     "Debuggers",
     "Snippets"
diff --git a/project/Rat.scala b/project/Rat.scala
index 451d92f..f2bd6df 100644
--- a/project/Rat.scala
+++ b/project/Rat.scala
@@ -26,8 +26,8 @@ object Rat {
     file("snippets/dfdl.json"),
     file("package.json"),
     file(".prettierrc"),
-    // ignore images - daffiodil.jpg
-    file("images/daffodil.jpg"),
+    // ignore images - daffiodil.ico
+    file("images/daffodil.ico"),
     // yarn and rpm generated files
     file("yarn.lock"),
     file("package-lock.json")

Reply via email to